pub struct ChainSpec {
pub trust: TrustIdentity,
pub limited_agent: LimitedAgentIdentity,
pub members: Vec<MemberIdentity>,
pub validators: Vec<ValidatorIdentity>,
pub validator_emission_rate: EmissionRate,
}Fields
trust: TrustIdentitylimited_agent: LimitedAgentIdentitymembers: Vec<MemberIdentity>validators: Vec<ValidatorIdentity>validator_emission_rate: EmissionRateImplementations
Sourceimpl ChainSpec
impl ChainSpec
Sourcepub fn generate_into<P: AsRef<Path> + Debug>(
&self,
chain_spec_template_zip: P,
target_dir: P,
) -> Result<PathBuf>
pub fn generate_into<P: AsRef<Path> + Debug>( &self, chain_spec_template_zip: P, target_dir: P, ) -> Result<PathBuf>
Generates a chain spec from the template zip published by thermite and the
context available to self, which currently comes from a YAML file.
The target directory must already exist.
Returns path to generated chain spec.